Frame

Struct Frame 

pub struct Frame {
    pub frame_type: Option<FrameType>,
    pub data: Option<Vec<u8>>,
    pub meta: Option<FrameMetadata>,
    pub port: Option<u8>,
    /* private fields */
}
A frame written to or read from a [fuchsia.net.tun/Device].

Required fields must always be provided to [fuchsia.net.tun/Port.WriteFrame] and are always present when returned by [fuchsia.net.tun/Port.ReadFrame].

Fields

frame_type: Option<FrameType>

The type identifying this frame’s payload.

Required.

data: Option<Vec<u8>>

The frame’s payload.

Valid iff non-empty.

Required.

meta: Option<FrameMetadata>

Extra frame metadata.

This is an opaque holder for extra information that is associated with Network Device data frames.

If not set, interpreted as empty.

port: Option<u8>

Frame’s destination or source port identifier.

Required.